@@ -1,4 +1,3 @@
-library(ggplot2)
 net_exp = as_sfnetwork(roxel)
 net_imp = as_sfnetwork(roxel, edges_as_lines = FALSE)
 
@@ -8,14 +7,16 @@ test_that("plot accepts sfnetworks with spatially implicit edges", {
   expect_silent(plot(net_imp, draw_lines = FALSE))
 })
 test_that("autplot returns a ggplot with two layers", {
-  g = autoplot(net_exp)
+  skip_if_not_installed("ggplot2")
+  g = ggplot2::autoplot(net_exp)
   expect_s3_class(g, "gg")
   expect_s3_class(g, "ggplot")
   expect_equal(length(g$layers), 2)
 })
 test_that("autoplot shows a message when implicit edges are passed", {
+  skip_if_not_installed("ggplot2", "3.0.0")
   expect_message(
-    autoplot(net_imp),
+    ggplot2::autoplot(net_imp),
     "Spatially implicit edges are drawn as lines"
   )
 })
